<?php
require_once __DIR__ . '/installation/database.php';

try {
    $pdo = new PDO("mysql:host=$db_host;dbname=$db_name", $db_user, $db_pass);
    $pdo->setAttribute(PDO::ATTR_ERRMODE, PDO::ERRMODE_EXCEPTION);
} catch (PDOException $e) {
    die("Database connection failed: " . $e->getMessage());
}

try {
    $stmt = $pdo->query("SELECT category_id, category_name FROM categories");
    $categories = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("Failed to fetch categories: " . $e->getMessage());
}

try {
    $stmt = $pdo->query("SELECT payee_id, friendly_name FROM payees");
    $payees = $stmt->fetchAll(PDO::FETCH_ASSOC);
} catch (PDOException $e) {
    die("Failed to fetch payees: " . $e->getMessage());
}

try {
    $stmt = $pdo->query("SELECT MAX(check_number) FROM checks");
    $nextCheck = $stmt->fetchColumn() + 1;
} catch (PDOException $e) {
    $nextCheck = 1;
}

if ($_SERVER["REQUEST_METHOD"] == "POST") {
    $checkData = [];
    $totalAmount = 0;
    foreach ($_POST as $key => $value) {
        if (strpos($key, 'check') === 0) {
            preg_match('/check(\d+)_(number|date|category|amount|memo1)/', $key, $matches);
            if ($matches) {
                $checkNumber = $matches[1];
                $field = $matches[2];
                $checkData[$checkNumber][$field] = $value;
                if ($field === 'amount') {
                    $totalAmount += floatval($value); 
                }
            }
        }
    }

    foreach ($checkData as $check) {
        if (isset($check['number']) && isset($check['date']) && isset($check['category']) && isset($check['amount'])) {
            try {
                $check_id = uniqid();
                $stmt = $pdo->prepare("INSERT INTO checks (check_id, check_number, date_written, category_id, amount, memo_1, payee_id) VALUES (?, ?, ?, ?, ?, ?, ?)");
                $stmt->execute([$check_id, $check['number'], $check['date'], $check['category'], -floatval($check['amount']), $check['memo1'] ?? null, $_POST['group_acct']]); // Store amount as negative, add payee_id
            } catch (PDOException $e) {
                echo "Error inserting check: " . $e->getMessage();
            }
        }
    }

    $memo = urlencode($_POST['group_memo'] ?? '');
    $payee = urlencode($_POST['group_acct'] ?? '');
    $amt = urlencode(number_format($totalAmount, 2, '.', '')); 

    header("Location: ./print.php?memo=$memo&payee=$payee&amt=$amt");
    exit;
}

?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" width=device-width, initial-scale=1.0">
    <title>Checks Register Debit Group</title>
    <link rel="stylesheet" href="./frontend-assets/css/style.css">
    <link rel="stylesheet" href="https://fonts.googleapis.com/css2?family=Material+Symbols+Outlined" />
</head>
<body>
    <div class="page-container">
        <aside></aside>
        <main>
            <h4>Debit Group</h4>
            <p>Use this tool to create a debit group, printing out multiple expenses as one check.</p>
            <div class="contain">
                <form method="post">
                    <table id="checkTable">
                        <tbody>
                            <tr id="row1">
                                <th>*Check Number</th>
                                <th>*Date</th>
                                <th>*Category</th>
                                <th>*Amount</th>
                                <th>Memo 1</th>
                            </tr>
                            <tr class="checkRow">
                                <td><input class="table-input number-input" type="text" autocomplete="off" name="check1_number" required></td>
                                <td><input class="table-input" type="date" name="check1_date" required></td>
                                <td>
                                    <select class="table-input" name="check1_category" required>
                                        <?php foreach ($categories as $category): ?>
                                            <option value="<?php echo $category['category_id']; ?>"><?php echo $category['category_name']; ?></option>
                                        <?php endforeach; ?>
                                    </select>
                                </td>
                                <td><input class="table-input money-input" type="text" autocomplete="off" name="check1_amount" required></td>
                                <td><input class="table-input" type="text" autocomplete="off" name="check1_memo1"></td>
                            </tr>
                        </tbody>
                    </table>
                    <input type="text" placeholder="Group Memo" name="group_memo">
                    <select name="group_acct">
                        <?php foreach ($payees as $payee): ?>
                            <option value="<?php echo $payee['payee_id']; ?>"><?php echo $payee['friendly_name']; ?></option>
                        <?php endforeach; ?>
                    </select>
                    <input type="submit" value="Print Group">
                </form>
            </div>
        </main>
    </div>
    <script>
        let nextCheckNumber = <?php echo $nextCheck; ?>;
        function addNewRow() {
            const table = document.getElementById('checkTable').getElementsByTagName('tbody')[0];
            const rows = table.getElementsByClassName('checkRow');
            const lastRow = rows[rows.length - 1];

            if (!lastRow) return;

            const newRow = lastRow.cloneNode(true);
            const newIndex = rows.length + 1;

            newRow.querySelectorAll('input, select').forEach(input => {
                input.name = input.name.replace(/check\d+/, `check${newIndex}`);
                if (input.type === 'text' || input.tagName === 'SELECT' || input.type === 'date') {
                    input.value = '';
                }
            });

            newRow.querySelectorAll('input,select').forEach(input=>{
                input.addEventListener('input', checkInputs);
            })
            table.appendChild(newRow);
        }

        function removeRequiredIfEmpty() {
            const table = document.getElementById('checkTable').getElementsByTagName('tbody')[0];
            const rows = table.getElementsByClassName('checkRow');
            const lastRow = rows[rows.length - 1];
            if (!lastRow) return;

            const allEmpty = Array.from(lastRow.querySelectorAll('input, select')).every(input => !input.value);

            lastRow.querySelectorAll('[required]').forEach(element => {
                if (allEmpty) {
                    element.removeAttribute('required');
                } else {
                    element.setAttribute('required', '');
                }
            });
        }

        function checkInputs(e) {
            const row = e.target.closest('.checkRow');
            const numberInput = row.querySelector('input[name*="number"]');
            const dateInput = row.querySelector('input[name*="date"]');
            const categoryInput = row.querySelector('select[name*="category"]');
            const amountInput = row.querySelector('input[name*="amount"]');

            if (numberInput && dateInput && categoryInput && amountInput){
                if (numberInput.value.trim() !== '' && dateInput.value.trim() !== '' && categoryInput.value && amountInput.value.trim() !== '') {
                    if (!numberInput.value) {
                        numberInput.value = nextCheckNumber++;
                    }
                    addNewRow();
                    row.querySelectorAll('input, select').forEach(input => {
                        input.removeEventListener('input', checkInputs);
                    });
                }
            }
            removeRequiredIfEmpty();
        }

        // Attach the event listener to the first row on page load
        const firstRowNumberInput = document.querySelector('input[name="check1_number"]');
        if (firstRowNumberInput){
            firstRowNumberInput.value = nextCheckNumber++;
            document.querySelector('.checkRow').querySelectorAll('input, select').forEach(input => {
                input.addEventListener('input', checkInputs);
            });
        }

    </script>
    <script>
        async function loadMenu() {
            try {
                const response = await fetch('./frontend-assets/templates/menu.html');
                if (!response.ok) {
                    throw new Error(`HTTP error! status: ${response.status}`);
                }
                const menuHtml = await response.text();
                const asideElement = document.querySelector('aside');
                if (asideElement) {
                    asideElement.innerHTML = menuHtml;
                } else {
                    console.error("Aside element not found");
                }
            } catch (error) {
                console.error('Error loading menu:', error);
            }
        }
        loadMenu();
        </script>
        <script src="./frontend-assets/js/validation.js"></script>
</body>
</html>